import { Subject } from 'rxjs';
import { TabExpViewBase } from '@/studio-core';
import EAMWorkOrderService from '@/service/eamwork-order/eamwork-order-service';
import EAMWorkOrderAuthService from '@/authservice/eamwork-order/eamwork-order-auth-service';
import TabExpViewEngine from '@engine/view/tab-exp-view-engine';
import EAMWorkOrderUIService from '@/uiservice/eamwork-order/eamwork-order-ui-service';

/**
 * 工单信息视图基类
 *
 * @export
 * @class EAMWorkOrderInfoViewBase
 * @extends {TabExpViewBase}
 */
export class EAMWorkOrderInfoViewBase extends TabExpViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMWorkOrderInfoViewBase
     */
    protected appDeName: string = 'eamworkorder';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMWorkOrderInfoViewBase
     */
    protected appDeKey: string = 'workorderid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMWorkOrderInfoViewBase
     */
    protected appDeMajor: string = 'workordername';

    /**
     * 实体服务对象
     *
     * @type {EAMWorkOrderService}
     * @memberof EAMWorkOrderInfoViewBase
     */
    protected appEntityService: EAMWorkOrderService = new EAMWorkOrderService;

    /**
     * 实体权限服务对象
     *
     * @type EAMWorkOrderUIService
     * @memberof EAMWorkOrderInfoViewBase
     */
    public appUIService: EAMWorkOrderUIService = new EAMWorkOrderUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMWorkOrderInfoViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMWorkOrderInfoViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamworkorder.views.infoview.caption',
        srfTitle: 'entities.eamworkorder.views.infoview.title',
        srfSubTitle: 'entities.eamworkorder.views.infoview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMWorkOrderInfoViewBase
     */
    protected containerModel: any = {
        view_tabexppanel: { name: 'tabexppanel', type: 'TABEXPPANEL' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = '2fc820c040c33d878fc98791e3ad6d80';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMWorkOrderInfoViewBase
     */
    public engine: TabExpViewEngine = new TabExpViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMWorkOrderInfoViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            keyPSDEField: 'eamworkorder',
            majorPSDEField: 'workordername',
            isLoadDefault: true,
        });
    }


}